<?php

namespace Drupal\Tests\ssf\Unit;

use Drupal\Tests\UnitTestCase;
use Drupal\ssf\Lexer;

/**
 * Tests for the Lexer.
 *
 * @coversDefaultClass \Drupal\ssf\Lexer
 * @group ssf
 */
class LexerTest extends UnitTestCase {
  public function testIsValid() {
    $logger_factory = $this->createMock('\Drupal\Core\Logger\LoggerChannelFactoryInterface');
    $lexer = new Lexer($logger_factory);

    $isValid = new \ReflectionMethod($lexer, 'isValid');
    $isValid->setAccessible(TRUE);

    $this->assertFalse($isValid->invokeArgs($lexer, ['bayes*']));
    $this->assertFalse($isValid->invokeArgs($lexer, ['a']));
    $this->assertFalse($isValid->invokeArgs($lexer, ['abcdefghijklmnopqrstuvwxyzABCDEFG']));
    $this->assertTrue($isValid->invokeArgs($lexer, ['abcdefgh']));
    $this->assertFalse($isValid->invokeArgs($lexer, ['12345']));
  }

  public function provideTestTokens() {
    return [
      [['test' => 1], 'test'],
      [['test' => 2], 'test test'],
      [['test' => 1, '<p>' => 1, '</p>' => 1], '<p>test</p>'],
      [['Visit' => 1, 'Google' => 1, 'find' => 1, 'your' => 1, 'answer' => 1,
        '</a>' => 1, '<a...>' => 1, 'href' => 1, 'http' => 1, 'www' => 1,
        'google' => 1, 'com' => 1, 'www.google.com' => 1],
        'Visit <a href="http://www.google.com/">Google</a> to find your answer.'],
      [['bayes*no_tokens' => 1], 'no'],
    ];
  }

  /**
   * @dataProvider provideTestTokens
   */
  public function testGetTokens($expected, $text) {
    $logger_factory = $this->createMock('\Drupal\Core\Logger\LoggerChannelFactoryInterface');
    $lexer = new Lexer($logger_factory);

    $this->assertArrayEquals($expected, $lexer->getTokens($text));
  }
}